@@ -6,6 +6,6 @@ using namespace Rcpp;
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::plugins(cpp11)]]
 
-IntegerMatrix rcpp_get_coocurrence_matrix(const IntegerMatrix x,
+IntegerMatrix rcpp_get_coocurrence_matrix(const IntegerMatrix &x,
                                           const arma::imat directions);
 #endif // GET_COOCURRENCE_MATRIX_H
